@@ -1,7 +1,10 @@
 import contextlib
 import io
+import os
 import pickle
 import sys
+import tempfile
+import zipfile
 
 from PIL import Image
 
@@ -87,12 +90,22 @@ class Classifier(Wrapper):
         else:
             return [(name, score) for name, score in res][:num]
 
-    def dump(self, file_handler) -> None:
+    def dump(self, file, mod="tf") -> None:
         """dump.
 
         :param file_handler:
         :rtype: None
         """
         self.score = self.model.get_metrics_result()
-        with nostdout():
-            pickle.dump(self, file_handler)
+        with zipfile.ZipFile(file, "w") as szip:
+            with tempfile.TemporaryDirectory() as tempdir:
+                self.model.save(os.path.join(tempdir, "tf_model"))
+                for root, dirs, files in os.walk(os.path.join(tempdir, "tf_model")):
+                    for file in files:
+                        szip.write(
+                            os.path.join(root, file),
+                            os.path.relpath(os.path.join(root, file), tempdir),
+                        )
+                self.model = None
+                pickle.dump(self, open(os.path.join(tempdir, "model.imlab"), "wb"))
+                szip.write(os.path.join(tempdir, "model.imlab"), "model.imlab")
