@@ -3,8 +3,11 @@ import io
 import os
 import pickle
 import sys
+import tempfile
+import zipfile
 from collections import OrderedDict
 
+import tensorflow as tf
 import torch
 
 from .extractor import Extractor
@@ -39,6 +42,18 @@ def load_torch(weight: str, classes: list, image_size: int) -> Extractor:
     return Extractor(image_size=image_size, model=model, classes=classes)
 
 
+def load_tf(path):
+    with zipfile.ZipFile(path, "r") as szip:
+        file = szip.read("model.imlab")
+        model = pickle.load(io.BytesIO(file))
+        with tempfile.TemporaryDirectory() as tempdir:
+            szip.extractall(os.path.join(tempdir, "model"))
+            model.model = tf.keras.models.load_model(
+                os.path.join(tempdir, "model", "tf_model")
+            )
+    return model
+
+
 def load(model: str = "yoloV7_coco.extractor") -> Extractor:
     """load. Load model
 
