@@ -159,6 +159,7 @@ class Train(Wrapper):
         learning_rate: float = 1e-3,
         path_chkp: str = "",
         early_stop=True,
+        metric="accuracy",
     ) -> object:
         """train.
 
@@ -177,7 +178,7 @@ class Train(Wrapper):
             learning_rate=learning_rate, weight_decay=1e-4
         )
         self.model.compile(
-            loss="categorical_crossentropy", optimizer=optimizer, metrics=["accuracy"]
+            loss="categorical_crossentropy", optimizer=optimizer, metrics=[metric]
         )
         callbacks = []
         if path_chkp != "":
@@ -185,7 +186,7 @@ class Train(Wrapper):
                 os.mkdir(path_chkp)
             checkpoint = tf.keras.callbacks.ModelCheckpoint(
                 filepath=path_chkp,
-                monitor="val_accuracy",
+                monitor="val_" + metric,
                 verbose=1,
                 save_weights_only=True,
                 save_best_only=True,
@@ -194,7 +195,7 @@ class Train(Wrapper):
             callbacks += [checkpoint]
         if early_stop:
             early_stopping = tf.keras.callbacks.EarlyStopping(
-                monitor="val_accuracy",
+                monitor="val_" + metric,
                 min_delta=0,
                 patience=3,
                 verbose=1,
@@ -235,6 +236,7 @@ def train(
     checkpoint: str = "",
     add: bool = False,
     early_stop=True,
+    metric="accuracy",
 ) -> Classifier:
     """train.
 
@@ -251,7 +253,12 @@ def train(
     :rtype: Classifier
     """
     if checkpoint == "" and not add:
-        trainer = Train(datas, model_type=model_type, image_size=image_size, mod="new")
+        trainer = Train(
+            datas,
+            model_type=model_type,
+            image_size=image_size,
+            mod="new",
+        )
     elif checkpoint == "" and add:
         image_size = 300
         model_type = ""
@@ -275,7 +282,11 @@ def train(
             mod="resume",
         )
     model = trainer.train(
-        path_chkp=checkpoint, steps=epochs, batch_size=batch_size, early_stop=early_stop
+        path_chkp=checkpoint,
+        steps=epochs,
+        batch_size=batch_size,
+        early_stop=early_stop,
+        metric=metric,
     )
     return Classifier(
         model=model,
